@@ -1,17 +1,18 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6calc.c
- * Version    : $Id: libipv6calc.c,v 1.3 2002/01/20 09:44:15 peter Exp $
+ * Version    : $Id: libipv6calc.c,v 1.5 2002/02/25 22:55:54 peter Exp $
  * Copyright  : 2001-2002 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function libary for conversions
- *
  */
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <ctype.h>
+
 /*
 #if defined(__NetBSD__)
 */
@@ -31,6 +32,7 @@
 #include "ipv6calc.h"
 #include "libipv6addr.h"
 #include "librfc1884.h"
+#include "libipv6calc.h"
 
 
 /* function stores an IPv6 address string into a structure
@@ -54,6 +56,8 @@ int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6ad
 		fprintf(stderr, "%s: got input %s\n", DEBUG_function_name,  addrstring);
 	};
 	
+	ipv6addr_clearall(ipv6addrp);
+
 	/* save prefix length first, if available */
 	ipv6addrp->flag_prefixuse = 0; /* reset flag first */
 	addronlystring = strtok (addrstring, "/");
@@ -70,6 +74,7 @@ int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6ad
 		
 		if ( ipv6calc_debug & DEBUG_libipv6calc ) {
 			fprintf(stderr, "%s: prefix length %d\n", DEBUG_function_name, ipv6addrp->prefixlength);
+			fprintf(stderr, "%s: flag_prefixuse %d\n", DEBUG_function_name, ipv6addrp->flag_prefixuse);
 		};
 	};
 
@@ -180,6 +185,7 @@ int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6ad
 
 	if ( ipv6calc_debug & DEBUG_libipv6calc ) {
 		fprintf(stderr, "%s: First word is: %x, address info value: %x\n", DEBUG_function_name, ipv6addr_getword(ipv6addrp, 0), result);
+		fprintf(stderr, "%s: flag_prefixuse %d\n", DEBUG_function_name, ipv6addrp->flag_prefixuse);
 	};
 	
 	retval = 0;
@@ -216,7 +222,8 @@ int ipv6addrstruct_to_uncompaddr(ipv6calc_ipv6addr *ipv6addrp, char *resultstrin
 	if ( ipv6calc_debug & DEBUG_libipv6calc ) {
 		fprintf(stderr, "%s: result string: %s\n", DEBUG_function_name, resultstring);
 	};
-		
+	
+	retval = 0;	
 	return (retval);
 };
 #undef DEBUG_function_name
@@ -350,6 +357,7 @@ int ipv6addrstruct_to_fulluncompaddr(ipv6calc_ipv6addr *ipv6addrp, char *results
 		fprintf(stderr, "%s: result string: %s\n", DEBUG_function_name, resultstring);
 	};
 	
+	retval = 0;	
 	return (retval);
 };
 #undef DEBUG_function_name
@@ -498,3 +506,22 @@ int identifier_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_
 	return (retval);
 };
 #undef DEBUG_function_name
+
+
+/*
+ * function converts chars in a string to upcase
+ * in : pointer to a string
+ */
+#define DEBUG_function_name "libipv6calc/string_to_upcase"
+void string_to_upcase(char *string) {
+	int i;
+
+	if (strlen(string) > 0) {
+		for (i = 0; i < strlen(string); i++) {
+			string[i] = toupper(string[i]);
+		};
+	};
+
+	return;
+};
+#undef DEBUG_function_name
